@@ -133,6 +133,9 @@ pub struct JpegDecoder<T: ZByteReaderTrait> {
     // of this struct, we check if we can switch to a faster one which
     // depend on certain CPU extensions.
     pub(crate) idct_func: IDCTPtr,
+    /// Specialized IDCT when we can guarantee only few coefficients are non-zero.
+    ///
+    /// **The callee must uphold a contract**. See [`choose_idct_4x4_func`].
     pub(crate) idct_4x4_func: IDCTPtr,
     pub(crate) idct_1x1_func: IDCTPtr,
     // Color convert function which acts on 16 YCbCr values
@@ -864,15 +867,15 @@ where
                 }
                 (2, 1) => {
                     comp.sample_ratio = SampleRatios::H;
-                    choose_horizontal_samp_function(self.options.use_unsafe())
+                    choose_horizontal_samp_function(&self.options)
                 }
                 (1, 2) => {
                     comp.sample_ratio = SampleRatios::V;
-                    choose_v_samp_function(self.options.use_unsafe())
+                    choose_v_samp_function(&self.options)
                 }
                 (2, 2) => {
                     comp.sample_ratio = SampleRatios::HV;
-                    choose_hv_samp_function(self.options.use_unsafe())
+                    choose_hv_samp_function(&self.options)
                 }
                 (hs, vs) => {
                     comp.sample_ratio = SampleRatios::Generic(hs, vs);
